@@ -4,6 +4,7 @@ use warnings;
 use utf8;
 use Text::Amuse::Output::Image;
 use Text::Amuse::InlineElement;
+use Text::Amuse::Utils;
 # use Data::Dumper::Concise;
 use constant DEBUG => 0;
 
@@ -174,7 +175,10 @@ sub process {
         }
         if ($el->type eq 'startblock') {
             die "startblock with string passed!: " . $el->string if $el->string;
-            push @pieces, $self->blkstring(start => $el->block, start_list_index => $el->start_list_index),
+            push @pieces, $self->blkstring(start => $el->block,
+                                           start_list_index => $el->start_list_index,
+                                           language => $el->language,
+                                          ),
               $self->format_anchors($el);
         }
         elsif ($el->type eq 'stopblock') {
@@ -458,7 +462,9 @@ sub inline_elements {
                             (?<sec_footnote> \s*\{[1-9][0-9]*\}) |
                             (?<tag> \<
                                 (?<close>\/?)
-                                (?<tag_name> strong | em |  strike | del | sup |  sub  | sf | sc )
+                                (?<tag_name> strong | em |  strike | del | sup |  sub  | sf | sc |
+                                    \[(?<lang>[a-z-]+)\]
+                                )
                                 \>
                             ) |
                             (?<nobreakspace>  \~\~         ) |
@@ -478,11 +484,15 @@ sub inline_elements {
                                                         lang => $self->_lang,
                                                        );
         }
+        my $inlined_lang = delete $captures{lang};
+        if ($inlined_lang) {
+            $self->document->_add_to_other_language_codes($inlined_lang);
+        }
         my %args = (
                     string => $raw,
                     last_position => $position,
                     fmt => $self->fmt,
-                    lang => $self->_lang,
+                    lang => $inlined_lang || $self->_lang,
                    );
 
         if (delete $captures{tag}) {
@@ -1650,6 +1660,26 @@ sub blk_table {
 
 sub _build_blk_table {
     my $table = {
+                 languageswitch => {
+                                    start => {
+                                              html => sub {
+                                                  my %attrs = @_;
+                                                  my $lang = $attrs{language} || "en";
+                                                  return qq{<div lang="$lang">\n};
+                                              },
+                                              ltx => sub {
+                                                  my %attrs = @_;
+                                                  my $iso = $attrs{language} || "en";
+                                                  my $lang = Text::Amuse::Utils::language_mapping()->{$iso};
+                                                  return sprintf("\\begin{otherlanguage}{%s}\n",
+                                                                 $lang || "english");
+                                              }
+                                             },
+                                    stop => {
+                                             html => sub { return qq{</div>\n} },
+                                             ltx => "\\end{otherlanguage}\n",
+                                            },
+                                   },
             'rtl' => {
                       start => {
                                 html => '<div dir="rtl">',
